==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/MediaConvert/GetQueue.pm <==

package Paws::MediaConvert::GetQueue;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'name', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetQueue');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2017-08-29/queues/{name}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::MediaConvert::GetQueueResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MediaConvert::GetQueue - Arguments for method GetQueue on L<Paws::MediaConvert>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetQueue on the
L<AWS Elemental MediaConvert|Paws::MediaConvert> service. Use the attributes of this class
as arguments to method GetQueue.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetQueue.

=head1 SYNOPSIS

    my $mediaconvert = Paws->service('MediaConvert');
    my $GetQueueResponse = $mediaconvert->GetQueue(
      Name => 'My__string',

    );

    # Results:
    my $Queue = $GetQueueResponse->Queue;

    # Returns a L<Paws::MediaConvert::GetQueueResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/mediaconvert/GetQueue>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the queue.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetQueue in L<Paws::MediaConvert>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/MediaConvert/GetQueue.pm <==

package Paws::MediaConvert::GetQueue;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'name', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetQueue');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2017-08-29/queues/{name}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::MediaConvert::GetQueueResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MediaConvert::GetQueue - Arguments for method GetQueue on L<Paws::MediaConvert>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetQueue on the
L<AWS Elemental MediaConvert|Paws::MediaConvert> service. Use the attributes of this class
as arguments to method GetQueue.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetQueue.

=head1 SYNOPSIS

    my $mediaconvert = Paws->service('MediaConvert');
    my $GetQueueResponse = $mediaconvert->GetQueue(
      Name => 'My__string',

    );

    # Results:
    my $Queue = $GetQueueResponse->Queue;

    # Returns a L<Paws::MediaConvert::GetQueueResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/mediaconvert/GetQueue>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the queue that you want information about.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetQueue in L<Paws::MediaConvert>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
